Package 'OSCA.intro'

Title: Introduction to OSCA
Description: Deploys the introduction to the "Orchestrating Single Cell Analysis with Bioconductor" book. This describes how to install R and Bioconductor packages, links out to some resources to learn R, describes how to load datasets into an R session, provides an overview of the SingleCellExperiment class, and performs a "quick start" demonstration for basic single-cell RNA-seq analyses. It is intended for readers with little-to-no computational background who are just getting started with analyses in R.
Authors: Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Ludwig Geistlinger [cre]
Maintainer: Ludwig Geistlinger <[email protected]>
License: CC BY 4.0
Version: 1.21.0
Built: 2026-05-29 09:42:27 UTC
Source: https://github.com/bioc/OSCA.intro

Help Index